@@ -88,12 +88,6 @@ if (empty($plugins)) {
 <?php
 	$style = '';
 
-	function sort_plugins($plug1, $plug2) {
-		return strnatcasecmp($plug1['Name'], $plug2['Name']);
-	}
-	
-	uksort($plugins, 'sort_plugins');
-
 	foreach($plugins as $plugin_file => $plugin_data) {
 		$style = ('class="alternate"' == $style|| 'class="alternate active"' == $style) ? '' : 'alternate';
 
