@@ -1,12 +1,12 @@
 <?php
 // ** MySQL settings ** //
-define('DB_NAME', 'wordpress');     // The name of the database
+define('DB_NAME', 'wordpress');    // The name of the database
 define('DB_USER', 'username');     // Your MySQL username
 define('DB_PASSWORD', 'password'); // ...and password
-define('DB_HOST', 'localhost');     // 99% chance you won't need to change this value
+define('DB_HOST', 'localhost');    // 99% chance you won't need to change this value
 
-// Change the prefix if you want to have multiple blogs in a single database.
-$table_prefix  = 'wp_';   // example: 'wp_' or 'b2' or 'mylogin_'
+// You can have multiple installations in one database if you give each a unique prefix
+$table_prefix  = 'wp_';   // Only numbers, letters, and underscores please!
 
 // Change this to localize WordPress.  A corresponding MO file for the
 // chosen language must be installed to wp-includes/languages.
@@ -14,7 +14,7 @@ $table_prefix  = 'wp_';   // example: 'wp_' or 'b2' or 'mylogin_'
 // to enable German language support.
 define ('WPLANG', '');
 
-/* Stop editing */
+/* That's all, stop editing! Happy blogging. */
 
 define('ABSPATH', dirname(__FILE__).'/');
 require_once(ABSPATH.'wp-settings.php');
