@@ -1,12 +1,13 @@
 
 <hr />
 <div id="footer">
+<!-- If you'd like to support WordPress, having the "powered by" link someone on your blog is the best way, it's our only promotion or advertising. -->
 	<p>
 		<?php bloginfo('name'); ?> is proudly powered by 
-		<a href="http://wordpress.org">WordPress</a>
+		<a href="http://wordpress.org/">WordPress</a>
 		<br /><a href="feed:<?php bloginfo('rss2_url'); ?>">Entries (RSS)</a>
 		and <a href="feed:<?php bloginfo('comments_rss2_url'); ?>">Comments (RSS)</a>.
-		<!-- <?php echo $wpdb->num_queries; ?> queries. <?php timer_stop(1); ?> seconds. -->
+		<!-- <?php echo get_num_queries(); ?> queries. <?php timer_stop(1); ?> seconds. -->
 	</p>
 </div>
 </div>
@@ -15,6 +16,5 @@
 <?php /* "Just what do you think you're doing Dave?" */ ?>
 
 		<?php wp_footer(); ?>
-
 </body>
-</html>
\ No newline at end of file
+</html>
